use Test::Base;

__DATA__
=== Complex generic manipulation
--- (test) lines chomp Split Reverse Join=\s reverse join=\n
Hey
I Like Ike
Give Peace A Chance
Love Is The Answer
--- (flipper) chomp
Answer The Is Love
Chance A Peace Give
Ike Like I
Hey
